### Name: tmle
### Title: Targeted Maximum Likelihood Estimation of Additive Treatment
###   Effect (Lite)
### Aliases: tmle


### ** Examples

library(tmleLite)

# generate data
  n <- 500
  W <- matrix(rnorm(n*3), ncol=3)
  A <- rbinom(n,1, 1/(1+exp(-(.1*W[,1] - .1*W[,2] + .5*W[,3]))))
  Y <- A + 2*W[,1] + W[,3] + W[,2]^2 + rnorm(n)
  colnames(W) <- paste("W",1:3, sep="")

# Example 1. Simplest function invocation 
# DSA called to estimate Q, g_A.
# Because Delta is not supplied, all outcomes are known to be measured.
#   
  result1 <- tmle(Y,A,W)
  summary(result1)

# Example 2: Binary outcome 
# DSA called to estimate Q
# known treatment mechanism, g_A, is user supplied 
# 
  A.ex2 <- rbinom(n,1,.5)
  Y.ex2 <- A.ex2 + 2*W[,1] + W[,3] + W[,2]^2 + rnorm(n)
  result2 <- tmle(Y=Y.ex2,A=A.ex2,W, g_A =rep(.5, length(Y)))
  summary(result2)

# Example 3: 
# User-supplied (misspecified) model for Q, 
# DSA called to estimate g_A, g_M
# approx. 20

  Delta <- rbinom(n, 1, 1/(1+exp(-(1.7-1*W[,1]))))
  result3 <- tmle(Y,A,W, Delta=Delta, Q=Y~A+W1+W2+W3)
  summary(result3)



